pychemia.searcher.tests package
===============================

.. automodule:: pychemia.searcher.tests
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

pychemia.searcher.tests.test_searcher module
--------------------------------------------

.. automodule:: pychemia.searcher.tests.test_searcher_clusters
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: pychemia.searcher.tests.test_searcher_functions
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: pychemia.searcher.tests.test_searcher_noncollinear
    :members:
    :undoc-members:
    :show-inheritance:
